#!/usr/bin/env python3
import sys
from functools import lru_cache
from sys import setrecursionlimit
setrecursionlimit(10**9)


class BaseSolution:
    def __init__(self, in_stream=sys.stdin, out_stream=sys.stdout):
        self.in_stream = in_stream
        self.out_stream = out_stream

    def read(self):
        raise NotImplemented()

    def solve(self):
        raise NotImplemented()

    def write(self):
        raise NotImplemented()

    def readInts(self):
        return list(map(int, self.input().split()))

    def print(self, *args, **kwargs):
        print(*args, file=self.out_stream, **kwargs)

    def input(self, *args, **kwargs):
        return self.in_stream.readline().rstrip('\n\r')

class BaseCoCoConcentricSolution(BaseSolution):
    def read(self):
        self.point1 = self.readInts()
        self.L1 = self.readInts()[1:]
        self.point2 = self.readInts()
        self.L2 = self.readInts()[1:]
        self.N = len(self.L1) + len(self.L2)

    def solve(self):
        self.dist = self.distanceCalculate()
        self.strict_intersections = self.strictIntersectionsCount()
        self.vertexes = 2 * self.N + 2 * self.strict_intersections
        self.connected_components = self.connectedComponentsCount()
        self.edges = 4*self.strict_intersections + 2*self.N
        self.faces = self.connected_components + self.edges - self.vertexes

    def distanceCalculate(self):
        from math import sqrt
        return sqrt((self.point1[0]-self.point2[0])**2 + (self.point1[1]-self.point2[1])**2)

    def write(self):
        self.print(self.faces)

        print('Vertexes:', self.vertexes, file=sys.stderr)
        print('Edges:', self.edges, file=sys.stderr)
        print('Components:', self.connected_components, file=sys.stderr)
        print('Strict Intersections:', self.strict_intersections, file=sys.stderr)

    def strictIntersectionsCount(self):
        raise NotImplemented()

    def connectedComponentsCount(self):
        raise NotImplemented()


class SquareCoCoConcentricSolution(BaseCoCoConcentricSolution):
    EPS = 1e-7

    def isStrictIntersects(self, i, j):
        return  (self.L1[i] + self.L2[j] > self.dist + self.EPS) \
                and (abs(self.L1[i] - self.L2[j]) < self.dist - self.EPS)

    def isTouches(self, i, j):
        return  abs(self.L1[i] + self.L2[j] - self.dist) < self.EPS \
                or abs(abs(self.L1[i] - self.L2[j]) - self.dist) < self.EPS

    def isIntersects(self, i, j):
        return self.isStrictIntersects(i, j) or self.isTouches(i, j)

    def predicatCount(self, predicat):
        cnt = 0
        for i in range(len(self.L1)):
            for j in range(len(self.L2)):
                if predicat(i, j):
                    cnt += 1
        return cnt

    def strictIntersectionsCount(self):
        return self.predicatCount(self.isStrictIntersects)

    def connectedComponentsCount(self):
        colors1 = [None] * len(self.L1)
        colors2 = [None] * len(self.L2)
        color = 0

        def dfs1(v):
            colors1[v] = color
            for u in range(len(colors2)):
                if colors2[u] is None and self.isIntersects(v, u):
                    dfs2(u)

        def dfs2(v):
            colors2[v] = color
            for u in range(len(colors1)):
                if colors1[u] is None and self.isIntersects(u, v):
                    dfs1(u)

        for colors, dfs in ((colors1, dfs1), (colors2, dfs2)):
            for i in range(len(colors)):
                if colors[i] is None:
                    dfs(i)
                    color += 1

        return color


class LinearCoCoConcentricSolution(SquareCoCoConcentricSolution):
    def isInside(self, i, j):
        if j == len(self.L2):
            return True
        if i == -1:
            return self.L2[j] > self.dist - self.EPS
        if i == len(self.L1) or j == -1:
            return False
        return -self.L1[i] > self.dist - self.L2[j] - self.EPS and \
               self.L1[i] < self.dist + self.L2[j] + self.EPS

    def isAround(self, i, j):
        if i == len(self.L1):
            return True
        if j == -1:
            return self.L1[i] > self.dist - self.EPS
        if j == len(self.L2) or i == -1:
            return False
        return self.L2[j] + self.dist < self.L1[i] + self.EPS \
               and self.dist - self.L2[j] > - self.L1[i] - self.EPS

    def isIndependent(self, i, j):
        if i == -1 or j == -1 or i == len(self.L1) or j == len(self.L2):
            return not self.isInside(i, j) and not self.isAround(i, j)
        else:
            return not self.isInside(i, j) and \
                   not self.isAround(i, j) and \
                   not self.isStrictIntersects(i, j)

    def solve(self):
        self.intersegs = [None] * len(self.L1)
        return super().solve()

    def update_interseg(self, i, seg):
        if seg is None:
            return
        if isinstance(seg, int):
            seg = (seg, seg)
        if seg[0] > seg[1]:
            return
        if self.intersegs[i] is None:
            self.intersegs[i] = seg
        else:
            if self.intersegs[i][0] == seg[1] + 1:
                self.intersegs[i] = (seg[0], self.intersegs[i][1])
            elif self.intersegs[i][1] == seg[0] - 1:
                self.intersegs[i] = (self.intersegs[i][0], seg[1])
            else:
                raise Exception('Failed to update interseg', self.intersegs[i], seg)

    def strictIntersectionsCount(self):
        cnt = 0
        i = 0
        cur = 0

        around = 0
        indep = len(self.L2)

        while i < len(self.L1):
            if self.isAround(i, -1):
                break
            while not self.isIndependent(i, indep):
                indep -= 1
            while not self.isInside(i, around):
                around += 1
            cnt += around - indep - 1
            self.update_interseg(i, (indep+1, around-1))
            i += 1
        if i == len(self.L1):
            return cnt

        left = -1
        right = 0
        while i < len(self.L1):
            while self.isAround(i, left + 1):
                left += 1
            while not self.isInside(i, right):
                right += 1
            cnt += right - left - 1
            self.update_interseg(i, (left+1, right-1))
            i += 1

        return cnt

    def connectedComponentsCount(self):
        cnt = 0
        used = [False] * len(self.L2)
        prev = None
        last = None
        minc, maxc = float('+inf'), float('-inf')
        for seg in self.intersegs:
            if seg is None or prev is None or \
                not (
                    prev[0] <= seg[0]  <= prev[1] or \
                    prev[0] <= seg[1]  <= prev[1] or \
                    seg[0]  <= prev[0] <= seg[1] or \
                    seg[0]  <= prev[1] <= seg[1] \
                ):
                cnt += 1
            if seg is not None and last is not None:
                if seg[1] < last[0]:
                    cnt += last[0] - seg[1] - 1
                if seg[0] > last[1]:
                    cnt += seg[0] - last[1] - 1
            prev = seg
            if seg is not None:
                last = seg
                minc = min(seg[0], minc)
                maxc = max(seg[1], maxc)

        if minc != float('+inf'):
            cnt += minc
            cnt += len(self.L2) - maxc - 1
        else:
            cnt += len(self.L2)

        return cnt

class CoCoConcentricSolution(LinearCoCoConcentricSolution):
    pass

if __name__ == '__main__':
    solution = CoCoConcentricSolution()
    solution.read()
    solution.solve()
    solution.write()

